Method: ActiveRecord::ConnectionAdapters::PostgreSQLAdapter#quote_sequence
- Defined in:
- lib/active_record/postgresql_extensions/adapter_extensions.rb
#quote_sequence(name) ⇒ Object
Quoting method for sequences. This really just goes to the quoting method for table names, as sequences can belong to specific schemas.
148 149 150 |
# File 'lib/active_record/postgresql_extensions/adapter_extensions.rb', line 148 def quote_sequence(name) quote_generic_with_schema(name) end |